@@ -76,8 +76,11 @@ namespace claw
     if ( !(b) )
       {
         std::cerr << file << ":" << line << "\n\t"
-                  << func << " : \n" << s << std::endl;
+                  << func << " : assertion failed\n\t" << s << std::endl;
+
+#ifndef CLAW_SOFT_ASSERT
         abort();
+#endif
       }
   } // claw::debug_assert()
 
