@@ -27,5 +27,9 @@ int main()
   claw::text::squeeze( s4, "ab" );
   std::cout << "squeeze '" << s3 << "' = '" << s4 << "'" << std::endl;
 
+  s4 = s;
+  claw::text::replace( s4, std::string("ab"), std::string("C") );
+  std::cout << "replace '" << s << "' = '" << s4 << "'" << std::endl;
+
   return 0;
 }
